@@ -327,7 +327,7 @@ If OBJECT is a symbol it names a dot qualified static FIELD."
 			 field
                          (find field (#"getDeclaredFields" class) 
                                :key 'jfield-name :test 'equal))))
-	(#"setAccessible" jfield t)
+	(#"setAccessible" jfield +true+)
 	(values (#"get" jfield object) jfield))
       (if (symbolp object)
           (let ((class (find-java-class object)))
@@ -350,7 +350,7 @@ associated is used to look up the static FIELD."
 	     (jfield (if (java-object-p field)
 			 field
 		       (find field (#"getDeclaredFields" class) :key 'jfield-name :test 'equal))))
-	(#"setAccessible" jfield t)
+	(#"setAccessible" jfield +true+)
 	(values (#"set" jfield object value) jfield))
     (if (symbolp object)
 	(let ((class (find-java-class object)))
@@ -461,7 +461,7 @@ current classpath."
   (let ((classes-field 
 	 (find "classes" (#"getDeclaredFields" (jclass "java.lang.ClassLoader"))
 	       :key #"getName" :test 'equal)))
-    (#"setAccessible" classes-field t)
+    (#"setAccessible" classes-field +true+)
     (loop for classloader in (mapcar #'first (dump-classpath))
 	 append
 	 (loop with classesv = (#"get" classes-field classloader)
@@ -567,17 +567,19 @@ current classpath."
   "Return the items contained the java.lang.Iterable ITERABLE as a list."
  (declare (optimize (speed 3) (safety 0)))
  (let ((it (#"iterator" iterable)))
-   (with-constant-signature ((hasmore "hasMoreElements")
-			     (next "nextElement"))
-     (loop while (hasmore it)
-	collect (next it)))))
+   (with-constant-signature ((has-next "hasNext")
+			     (next "next"))
+     (loop :while (has-next it)
+	:collect (next it)))))
 
 (defun vector-to-list (vector)
+  "Return the elements of java.lang.Vector VECTOR as a list."
  (declare (optimize (speed 3) (safety 0)))
- (with-constant-signature ((hasmore "hasMoreElements")
+ (with-constant-signature ((has-more "hasMoreElements")
 			   (next "nextElement"))
-     (loop while (hasmore vector)
-	collect (next vector))))
+   (let ((elements (#"elements" vector)))
+     (loop :while (has-more elements)
+	:collect (next elements)))))
 
 (defun hashmap-to-hashtable (hashmap &rest rest &key (keyfun #'identity) (valfun #'identity) (invert? nil)
 				    table 
