@@ -4,8 +4,7 @@
 ;;; Public API
    #:resolve
 
-   #:resolve-dependencies
-   #:resolve-artifact
+   #:ensure-mvn-version
 
    #:find-mvn
 
@@ -13,11 +12,9 @@
 
    #:init
 
-;;; ASDF
-;;;   #:iri #:mvn
-;;;   #:ensure-parsed-mvn
-
 ;;; "Internal" API
+   #:resolve-dependencies
+   #:resolve-artifact
 
 ;;;; Maven 
    #:*mvn-libs-directory*
@@ -38,5 +35,5 @@
    #:*inhibit-add-to-classpath*))
 
 (defpackage #:abcl-asdf-test
-  (:use :cl #+nil :abcl-test-lisp) ;;; FIXME include some sort of test framework
+  (:use :cl :abcl-asdf)
   (:export #:run))
