@@ -2,7 +2,7 @@
  * Autoload.java
  *
  * Copyright (C) 2003-2006 Peter Graves
- * $Id: Autoload.java 14378 2013-02-13 19:54:49Z mevenson $
+ * $Id$
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -325,7 +325,8 @@ public class Autoload extends Function
     public static final Primitive RESOLVE = new pf_resolve();
     @DocString(name="resolve", 
                args="symbol",
-               doc="Force the symbol to be resolved via the autoloader mechanism.")
+               doc="Resolve the function named by SYMBOL via the autoloader mechanism.\n"
+               + "Returns either the function or NIL if no resolution was possible.")
     private static final class pf_resolve extends Primitive {
         pf_resolve() {
             super("resolve", PACKAGE_EXT, true, "symbol");
@@ -339,7 +340,7 @@ public class Autoload extends Function
                 autoload.load();
                 return symbol.getSymbolFunction();
             }
-            return fun;
+            return ((fun == null) ? NIL : fun);
         }
     }
 
@@ -392,7 +393,7 @@ public class Autoload extends Function
         autoload("cos", "MathFunctions");
         autoload("cosh", "MathFunctions");
         autoload("delete-file", "delete_file");
-        autoload("%delete-package", "PackageFunctions");
+        autoload(PACKAGE_SYS, "%delete-package", "PackageFunctions");
         autoload("echo-stream-input-stream", "EchoStream");
         autoload("echo-stream-output-stream", "EchoStream");
         autoload("exp", "MathFunctions");
@@ -428,7 +429,7 @@ public class Autoload extends Function
         autoload("hash-table-size", "HashTableFunctions");
         autoload("hash-table-test", "HashTableFunctions");
         autoload("hash-table-test", "HashTableFunctions");
-        autoload("%import", "PackageFunctions");
+        autoload(PACKAGE_SYS, "%import", "PackageFunctions");
         autoload("input-stream-p", "input_stream_p");
         autoload("integer-decode-float", "FloatFunctions");
         autoload("interactive-stream-p", "interactive_stream_p");
@@ -498,7 +499,7 @@ public class Autoload extends Function
         autoload("stream-element-type", "stream_element_type");
         autoload("stream-error-stream", "StreamError");
         autoload("stream-external-format", "stream_external_format");
-        autoload("%set-stream-external-format", "stream_external_format");
+        autoload(PACKAGE_SYS, "%set-stream-external-format", "Stream");
         autoload("stringp", "StringFunctions");
         autoload("sxhash", "HashTableFunctions");
         autoload("sxhash", "HashTableFunctions");
@@ -552,16 +553,13 @@ public class Autoload extends Function
         autoload(PACKAGE_SYS, "%%string=", "StringFunctions");
         autoload(PACKAGE_SYS, "%adjust-array", "adjust_array");
         autoload(PACKAGE_SYS, "%defpackage", "PackageFunctions");
-        autoload(PACKAGE_SYS, "%finalize-generic-function", "StandardGenericFunction", true);
-        autoload(PACKAGE_SYS, "%generic-function-lambda-list", "StandardGenericFunction", true);
-        autoload(PACKAGE_SYS, "%generic-function-name", "StandardGenericFunction", true);
-        autoload(PACKAGE_SYS, "set-generic-function-declarations", "StandardGenericFunction", true);
         autoload(PACKAGE_SYS, "%get-output-stream-bytes", "ByteArrayOutputStream"); //AS 20090325
         autoload(PACKAGE_SYS, "%get-output-stream-array", "ByteArrayOutputStream");
         autoload(PACKAGE_SYS, "%make-array", "make_array");
         autoload(PACKAGE_SYS, "%make-byte-array-input-stream", "ByteArrayInputStream"); //AS 20100317
         autoload(PACKAGE_SYS, "%make-byte-array-output-stream", "ByteArrayOutputStream"); //AS 20090325
         autoload(PACKAGE_SYS, "%make-condition", "make_condition", true);
+        autoload(PACKAGE_SYS, "%make-emf-cache", "EMFCache", true);
         autoload(PACKAGE_SYS, "%make-hash-table", "HashTableFunctions");
         autoload(PACKAGE_SYS, "%make-hash-table", "HashTableFunctions");
         autoload(PACKAGE_SYS, "%make-logical-pathname", "LogicalPathname", true);
@@ -572,6 +570,7 @@ public class Autoload extends Function
         autoload(PACKAGE_SYS, "%nstring-capitalize", "StringFunctions");
         autoload(PACKAGE_SYS, "%nstring-downcase", "StringFunctions");
         autoload(PACKAGE_SYS, "%nstring-upcase", "StringFunctions");
+        autoload(PACKAGE_SYS, "%reinit-emf-cache", "EMFCache", true);
         autoload(PACKAGE_SYS, "%run-shell-command", "ShellCommand");
         autoload(PACKAGE_SYS, "%server-socket-close", "server_socket_close");
         autoload(PACKAGE_SYS, "%set-arglist", "arglist");
@@ -579,14 +578,6 @@ public class Autoload extends Function
         autoload(PACKAGE_SYS, "%set-find-class", "LispClass", true);
         autoload(PACKAGE_SYS, "%set-class-direct-slots", "SlotClass", true);
         autoload(PACKAGE_SYS, "%set-function-info", "function_info");
-        autoload(PACKAGE_SYS, "%set-generic-function-lambda-list", "StandardGenericFunction", true);
-        autoload(PACKAGE_SYS, "%set-generic-function-name", "StandardGenericFunction", true);
-        autoload(PACKAGE_SYS, "%set-gf-required-args", "StandardGenericFunction", true);
-        autoload(PACKAGE_SYS, "%set-gf-optional-args", "StandardGenericFunction", true);
-        autoload(PACKAGE_SYS, "gf-required-args", "StandardGenericFunction", true);
-        autoload(PACKAGE_SYS, "gf-optional-args", "StandardGenericFunction", true);
-        autoload(PACKAGE_SYS, "%init-eql-specializations", "StandardGenericFunction", true);
-        autoload(PACKAGE_SYS, "%get-arg-specialization", "StandardGenericFunction", true);
         autoload(PACKAGE_SYS, "%set-symbol-macro", "Primitives");
         autoload(PACKAGE_SYS, "%simple-bit-vector-bit-and", "SimpleBitVector");
         autoload(PACKAGE_SYS, "%simple-bit-vector-bit-andc1", "SimpleBitVector");
@@ -599,15 +590,6 @@ public class Autoload extends Function
         autoload(PACKAGE_SYS, "%simple-bit-vector-bit-orc1", "SimpleBitVector");
         autoload(PACKAGE_SYS, "%simple-bit-vector-bit-orc2", "SimpleBitVector");
         autoload(PACKAGE_SYS, "%simple-bit-vector-bit-xor", "SimpleBitVector");
-        autoload(PACKAGE_SYS, "%slot-definition-allocation", "SlotDefinition", true);
-        autoload(PACKAGE_SYS, "%slot-definition-allocation-class", "SlotDefinition", true);
-        autoload(PACKAGE_SYS, "%slot-definition-initargs", "SlotDefinition", true);
-        autoload(PACKAGE_SYS, "%slot-definition-initform", "SlotDefinition", true);
-        autoload(PACKAGE_SYS, "%slot-definition-initfunction", "SlotDefinition", true);
-        autoload(PACKAGE_SYS, "%slot-definition-location", "SlotDefinition", true);
-        autoload(PACKAGE_SYS, "%slot-definition-name", "SlotDefinition", true);
-        autoload(PACKAGE_SYS, "%slot-definition-readers", "SlotDefinition", true);
-        autoload(PACKAGE_SYS, "%slot-definition-writers", "SlotDefinition", true);
         autoload(PACKAGE_SYS, "%socket-accept", "socket_accept");
         autoload(PACKAGE_SYS, "%socket-close", "socket_close");
         autoload(PACKAGE_SYS, "%socket-stream", "socket_stream");
@@ -627,14 +609,12 @@ public class Autoload extends Function
         autoload(PACKAGE_SYS, "%string>", "StringFunctions");
         autoload(PACKAGE_SYS, "%string>=", "StringFunctions");
         autoload(PACKAGE_SYS, "%time", "Time");
-        autoload(PACKAGE_SYS, "cache-emf", "StandardGenericFunction", true);
-        autoload(PACKAGE_SYS, "cache-slot-location", "StandardGenericFunction", true);
+        autoload(PACKAGE_SYS, "cache-emf", "EMFCache", true);
         autoload(PACKAGE_SYS, "canonicalize-logical-host", "LogicalPathname", true);
-        autoload(PACKAGE_SYS, "class-direct-slots", "SlotClass");
+        autoload(PACKAGE_SYS, "%class-direct-slots", "SlotClass");
         autoload(PACKAGE_SYS, "%float-bits", "FloatFunctions");
         autoload(PACKAGE_SYS, "coerce-to-double-float", "FloatFunctions");
         autoload(PACKAGE_SYS, "coerce-to-single-float", "FloatFunctions");
-        autoload(PACKAGE_SYS, "compute-class-direct-slots", "SlotClass", true);
         autoload(PACKAGE_SYS, "create-new-file", "create_new_file");
         autoload(PACKAGE_SYS, "default-time-zone", "Time");
         autoload(PACKAGE_SYS, "disassemble-class-bytes", "disassemble_class_bytes", true);
@@ -645,18 +625,8 @@ public class Autoload extends Function
         autoload(PACKAGE_SYS, "float-nan-p", "FloatFunctions", true);
         autoload(PACKAGE_SYS, "float-string", "FloatFunctions", true);
         autoload(PACKAGE_SYS, "function-info", "function_info");
-        autoload(PACKAGE_SYS, "%generic-function-argument-precedence-order","StandardGenericFunction", true);
-        autoload(PACKAGE_SYS, "generic-function-classes-to-emf-table","StandardGenericFunction", true);
-        autoload(PACKAGE_SYS, "generic-function-documentation","StandardGenericFunction", true);
-        autoload(PACKAGE_SYS, "generic-function-initial-methods","StandardGenericFunction", true);
-        autoload(PACKAGE_SYS, "%generic-function-method-class","StandardGenericFunction", true);
-        autoload(PACKAGE_SYS, "%generic-function-method-combination","StandardGenericFunction", true);
-        autoload(PACKAGE_SYS, "%generic-function-methods","StandardGenericFunction", true);
-        autoload(PACKAGE_SYS, "get-cached-emf", "StandardGenericFunction", true);
-        autoload(PACKAGE_SYS, "get-cached-slot-location", "StandardGenericFunction", true);
+        autoload(PACKAGE_SYS, "get-cached-emf", "EMFCache", true);
         autoload(PACKAGE_SYS, "get-function-info-value", "function_info");
-        autoload(PACKAGE_SYS, "gf-required-args", "StandardGenericFunction", true);
-        autoload(PACKAGE_SYS, "gf-optional-args", "StandardGenericFunction", true);
         autoload(PACKAGE_SYS, "hash-table-entries", "HashTableFunctions");
         autoload(PACKAGE_SYS, "hash-table-entries", "HashTableFunctions");
         autoload(PACKAGE_SYS, "layout-class", "Layout", true);
@@ -667,10 +637,9 @@ public class Autoload extends Function
         autoload(PACKAGE_SYS, "make-double-float", "FloatFunctions", true);
         autoload(PACKAGE_SYS, "make-file-stream", "FileStream");
         autoload(PACKAGE_SYS, "make-fill-pointer-output-stream", "FillPointerOutputStream");
-        autoload(PACKAGE_SYS, "make-forward-referenced-class", "ForwardReferencedClass", true);
         autoload(PACKAGE_SYS, "make-layout", "Layout", true);
         autoload(PACKAGE_SYS, "make-single-float", "FloatFunctions", true);
-        autoload(PACKAGE_SYS, "make-slot-definition", "SlotDefinition", true);
+        autoload(PACKAGE_SYS, "%make-slot-definition", "SlotDefinition", true);
         autoload(PACKAGE_SYS, "make-structure-class", "StructureClass");
         autoload(PACKAGE_SYS, "make-symbol-macro", "Primitives");
         autoload(PACKAGE_SYS, "psxhash", "HashTableFunctions");
@@ -678,22 +647,6 @@ public class Autoload extends Function
         autoload(PACKAGE_SYS, "puthash", "HashTableFunctions");
         autoload(PACKAGE_SYS, "remove-zip-cache-entry", "ZipCache");
         autoload(PACKAGE_SYS, "set-function-info-value", "function_info");
-        autoload(PACKAGE_SYS, "set-generic-function-argument-precedence-order","StandardGenericFunction", true);
-        autoload(PACKAGE_SYS, "set-generic-function-classes-to-emf-table","StandardGenericFunction", true);
-        autoload(PACKAGE_SYS, "set-generic-function-documentation","StandardGenericFunction", true);
-        autoload(PACKAGE_SYS, "set-generic-function-initial-methods","StandardGenericFunction", true);
-        autoload(PACKAGE_SYS, "set-generic-function-method-class","StandardGenericFunction", true);
-        autoload(PACKAGE_SYS, "set-generic-function-method-combination","StandardGenericFunction", true);
-        autoload(PACKAGE_SYS, "set-generic-function-methods","StandardGenericFunction", true);
-        autoload(PACKAGE_SYS, "set-slot-definition-allocation", "SlotDefinition", true);
-        autoload(PACKAGE_SYS, "set-slot-definition-allocation-class", "SlotDefinition", true);
-        autoload(PACKAGE_SYS, "set-slot-definition-initargs", "SlotDefinition", true);
-        autoload(PACKAGE_SYS, "set-slot-definition-initform", "SlotDefinition", true);
-        autoload(PACKAGE_SYS, "set-slot-definition-initfunction", "SlotDefinition", true);
-        autoload(PACKAGE_SYS, "set-slot-definition-location", "SlotDefinition", true);
-        autoload(PACKAGE_SYS, "set-slot-definition-name", "SlotDefinition", true);
-        autoload(PACKAGE_SYS, "set-slot-definition-readers", "SlotDefinition", true);
-        autoload(PACKAGE_SYS, "set-slot-definition-writers", "SlotDefinition", true);
         autoload(PACKAGE_SYS, "simple-list-remove-duplicates", "simple_list_remove_duplicates");
         autoload(PACKAGE_SYS, "single-float-bits", "FloatFunctions", true);
         autoload(PACKAGE_SYS, "%std-allocate-instance", "StandardObject", true);
