@@ -2,7 +2,7 @@
  * Java.java
  *
  * Copyright (C) 2002-2006 Peter Graves, Andras Simon
- * $Id: Java.java 14239 2012-11-09 17:28:12Z mevenson $
+ * $Id$
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -35,10 +35,6 @@ package org.armedbear.lisp;
 
 import static org.armedbear.lisp.Lisp.*;
 
-import java.beans.BeanInfo;
-import java.beans.IntrospectionException;
-import java.beans.Introspector;
-import java.beans.PropertyDescriptor;
 import java.lang.reflect.Array;
 import java.lang.reflect.Constructor;
 import java.lang.reflect.Field;
@@ -461,16 +457,20 @@ public final class Java
                     if (m == null)
                         error(new LispError("no such method"));
                 }
-            } else
-                error(new TypeError("wrong type: " + methodRef));
+            } else {
+              type_error(methodRef, Symbol.STRING);
+            }
             Object[] methodArgs = new Object[args.length-2];
             Class[] argTypes = m.getParameterTypes();
             for (int i = 2; i < args.length; i++) {
                 LispObject arg = args[i];
-                if (arg == NIL)
-                    methodArgs[i-2] = null;
-                else
-                    methodArgs[i-2] = arg.javaInstance(argTypes[i-2]);
+                if (arg.equals(NIL)) {
+                  methodArgs[i-2] = false;
+                } else if (arg.equals(T)) {
+                  methodArgs[i-2] = true;
+                } else {
+                  methodArgs[i-2] = arg.javaInstance(argTypes[i-2]);
+                }
             }
             m.setAccessible(true);
             Object result = m.invoke(null, methodArgs);
@@ -566,10 +566,12 @@ public final class Java
                 Object[] initargs = new Object[args.length-1];
                 for (int i = 1; i < args.length; i++) {
                     LispObject arg = args[i];
-                    if (arg == NIL)
-                        initargs[i-1] = null;
-                    else {
-                        initargs[i-1] = arg.javaInstance(argTypes[i-1]);
+                    if (arg.equals(NIL)) {
+                      initargs[i-1] = false ;
+                    } else if (arg.equals(T)) {
+                      initargs[i-1] = true;
+                    } else {
+                      initargs[i-1] = arg.javaInstance(argTypes[i-1]);
                     }
                 }
                 return JavaObject.getInstance(constructor.newInstance(initargs));
@@ -809,7 +811,7 @@ public final class Java
                 instance = instanceArg.javaInstance();
             }
             if(instance == null) {
-                return error(new ProgramError("JRESOLVE-METHOD: instance must not be null"));
+                return program_error("JRESOLVE-METHOD: instance must not be null.");
             }
             String methodName = methodArg.getStringValue();
             Object[] methodArgs = translateMethodArguments(args, 2);
@@ -882,11 +884,14 @@ public final class Java
 	    }
             methodArgs = new Object[argTypes.length];
             for (int i = 2; i < args.length; i++) {
-                LispObject arg = args[i];
-                if (arg == NIL)
-                    methodArgs[i-2] = null;
-                else
-                    methodArgs[i-2] = arg.javaInstance(argTypes[i-2]);
+              LispObject arg = args[i];
+              if (arg.equals(NIL)) {
+                methodArgs[i-2] = false;
+              } else if (arg.equals(T)) {
+                methodArgs[i-2] = true;
+              } else {
+                methodArgs[i-2] = arg.javaInstance(argTypes[i-2]);
+              }
             }
             if (!method.isAccessible()) {
                  // Possible for static member classes: see #229
@@ -927,12 +932,14 @@ public final class Java
 	int argCount = args.length - offs;
         Object[] javaArgs = new Object[argCount];
         for (int i = 0; i < argCount; ++i) {
-            Object x = args[i + offs];
-            if (x == NIL) {
-                javaArgs[i] = null;
-            } else {
-                javaArgs[i] = ((LispObject) x).javaInstance();
-            }
+          Object x = args[i + offs];
+          if (x.equals(NIL)) {
+            javaArgs[i] = false;
+          } else if (x.equals(T)) {
+            javaArgs[i] = true;
+          } else {
+            javaArgs[i] = ((LispObject) x).javaInstance();
+          }
         }
 	return javaArgs;
     }
@@ -1044,17 +1051,34 @@ public final class Java
         return result;
     }
 
+    private static boolean isAssignable(Class<?> from, Class<?> to) {
+        from = maybeBoxClass(from);
+        to = maybeBoxClass(to);
+        if (to.isAssignableFrom(from)) {
+            return true;
+        }
+        if (Byte.class.equals(from)) {
+            return Short.class.equals(to) || Integer.class.equals(to) || Long.class.equals(to) || Float.class.equals(to) || Double.class.equals(to);
+        } else if (Short.class.equals(from) || Character.class.equals(from)) {
+            return Integer.class.equals(to) || Long.class.equals(to) || Float.class.equals(to) || Double.class.equals(to);
+        } else if (Integer.class.equals(from)) {
+            return Long.class.equals(to) || Float.class.equals(to) || Double.class.equals(to);
+        } else if (Long.class.equals(from)) {
+            return Float.class.equals(to) || Double.class.equals(to);
+        } else if (Float.class.equals(from)) {
+            return Double.class.equals(to);
+        }
+        return false;
+    }
+
     private static boolean isApplicableMethod(Class<?>[] methodTypes,
             Object[] args) {
         for (int i = 0; i < methodTypes.length; ++i) {
             Class<?> methodType = methodTypes[i];
             Object arg = args[i];
-            if (methodType.isPrimitive()) {
-                Class<?> x = getBoxedClass(methodType);
-                if (!x.isInstance(arg)) {
-                    return false;
-                }
-            } else if (arg != null && !methodType.isInstance(arg)) {
+            if (arg == null) {
+                return !methodType.isPrimitive();
+            } else if (!isAssignable(arg.getClass(), methodType)) {
                 return false;
             }
         }
@@ -1063,18 +1087,12 @@ public final class Java
 
     private static boolean isMoreSpecialized(Class<?>[] xtypes, Class<?>[] ytypes) {
         for (int i = 0; i < xtypes.length; ++i) {
-            Class<?> xtype = xtypes[i];
-            if (xtype.isPrimitive()) {
-                xtype = getBoxedClass(xtype);
-            }
-            Class<?> ytype = ytypes[i];
-            if (ytype.isPrimitive()) {
-                ytype = getBoxedClass(ytype);
-            }
+            Class<?> xtype = maybeBoxClass(xtypes[i]);
+            Class<?> ytype = maybeBoxClass(ytypes[i]);
             if (xtype.equals(ytype)) {
                 continue;
             }
-            if (ytype.isAssignableFrom(xtype)) {
+            if (isAssignable(xtype, ytype)) {
                 return true;
             }
         }
@@ -1236,76 +1254,7 @@ public final class Java
 	    try {
 		return JavaObject.getInstance(o, c);
 	    } catch(ClassCastException e) {
-		return error(new TypeError(javaObject, new SimpleString(c.getName())));
-	    }
-        }
-    };
-
-    private static final Primitive JGET_PROPERTY_VALUE = new pf__jget_property_value();
-    @DocString(name="%jget-propety-value", args="java-object property-name",
-    doc="Gets a JavaBeans property on JAVA-OBJECT.\n" +
-        "SYSTEM-INTERNAL: Use jproperty-value instead.")
-    private static final class pf__jget_property_value extends Primitive
-    {
-        pf__jget_property_value() 
-        {
-	    super("%jget-property-value", PACKAGE_JAVA, false,
-                  "java-object property-name");
-        }
-    	
-        @Override
-        public LispObject execute(LispObject javaObject, LispObject propertyName) {
-			try {
-				Object obj = javaObject.javaInstance();
-				PropertyDescriptor pd = getPropertyDescriptor(obj, propertyName);
-				Object value = pd.getReadMethod().invoke(obj);
-				if(value instanceof LispObject) {
-				    return (LispObject) value;
-				} else if(value != null) {
-				    return JavaObject.getInstance(value, true);
-				} else {
-				    return NIL;
-				}
-			} catch (Exception e) {
-                return error(new JavaException(e));
-			}
-        }
-    };
-    
-    private static final Primitive JSET_PROPERTY_VALUE = new pf__jset_property_value();
-    @DocString(name="%jset-propety-value", args="java-object property-name value",
-    doc="Sets a JavaBean property on JAVA-OBJECT.\n" +
-        "SYSTEM-INTERNAL: Use (setf jproperty-value) instead.")
-    private static final class pf__jset_property_value extends Primitive
-    {
-        pf__jset_property_value()
-        {
-	    super("%jset-property-value", PACKAGE_JAVA, false,
-                  "java-object property-name value");
-        }
-    	
-        @Override
-        public LispObject execute(LispObject javaObject, LispObject propertyName, LispObject value) {
-	    Object obj = null;
-	    try {
-		obj = javaObject.javaInstance();
-		PropertyDescriptor pd = getPropertyDescriptor(obj, propertyName);
-		Object jValue;
-		//TODO maybe we should do this in javaInstance(Class)
-		if(value instanceof JavaObject) {
-		    jValue = value.javaInstance();
-		} else {
-		    if(Boolean.TYPE.equals(pd.getPropertyType()) ||
-		       Boolean.class.equals(pd.getPropertyType())) {
-			jValue = value != NIL;
-		    } else {
-			jValue = value != NIL ? value.javaInstance() : null;
-		    }
-		}
-		pd.getWriteMethod().invoke(obj, jValue);
-		return value;
-	    } catch (Exception e) {
-            return error(new JavaException(e));
+          return type_error(javaObject, new SimpleString(c.getName()));
 	    }
         }
     };
@@ -1338,19 +1287,6 @@ public final class Java
         }
     };
 
-    static PropertyDescriptor getPropertyDescriptor(Object obj, LispObject propertyName) throws IntrospectionException {
-        String prop = ((AbstractString) propertyName).getStringValue();
-        BeanInfo beanInfo = Introspector.getBeanInfo(obj.getClass());
-        for(PropertyDescriptor pd : beanInfo.getPropertyDescriptors()) {
-        	if(pd.getName().equals(prop)) {
-        		return pd;
-        	}
-        }
-        error(new LispError("Property " + prop + " not found in " + obj));
-
-        return null; // not reached
-    }
-    
     private static Class classForName(String className) {
 	return classForName(className, JavaClassLoader.getPersistentInstance());
     }
