@@ -2,7 +2,7 @@
  * Lisp.java
  *
  * Copyright (C) 2002-2007 Peter Graves <peter@armedbear.org>
- * $Id: Lisp.java 14378 2013-02-13 19:54:49Z mevenson $
+ * $Id$
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -383,6 +383,19 @@ public final class Lisp
     return Symbol.ERROR.execute(condition);
   }
 
+  public static final LispObject stackError()
+  {
+    pushJavaStackFrames();
+    return Symbol.ERROR.execute(new StorageCondition("Stack overflow."));
+  }
+
+  public static final LispObject memoryError(OutOfMemoryError exception)
+  {
+    pushJavaStackFrames();
+    return Symbol.ERROR.execute(new StorageCondition("Out of memory: "
+                                                     + exception.getMessage()));
+  }
+
   public static final int ierror(LispObject condition)
   {
     error(condition);
@@ -418,11 +431,20 @@ public final class Lisp
 
   public static final LispObject type_error(LispObject datum,
                                             LispObject expectedType)
-
   {
     return error(new TypeError(datum, expectedType));
   }
 
+  public static final LispObject program_error(String message)
+  {
+    return error(new ProgramError(message));
+  }
+
+  public static final LispObject program_error(LispObject initArgs)
+  {
+    return error(new ProgramError(initArgs));
+  }
+
   public static volatile boolean interrupted;
 
   public static synchronized final void setInterrupted(boolean b)
@@ -526,8 +548,8 @@ public final class Lisp
                 return evalCall(closure, ((Cons)obj).cdr, env, thread);
               }
             else
-              return error(new ProgramError("Illegal function object: " +
-                                             first.princToString()));
+              return program_error("Illegal function object: "
+                                   + first.princToString() + ".");
           }
       }
     else
@@ -1809,7 +1831,7 @@ public final class Lisp
   {
     if (obj instanceof Function)
       return obj;
-    if (obj instanceof StandardGenericFunction)
+    if (obj instanceof FuncallableStandardObject)
       return obj;
     if (obj instanceof Symbol)
       {
@@ -1839,7 +1861,7 @@ public final class Lisp
   {
     if (obj instanceof Package)
       return (Package) obj;
-    Package pkg = Packages.findPackage(javaString(obj));
+    Package pkg = getCurrentPackage().findPackage(javaString(obj));
     if (pkg != null)
       return pkg;
     error(new PackageError(obj.princToString() + " is not the name of a package."));
@@ -2147,7 +2169,7 @@ public final class Lisp
   public static final Symbol internInPackage(String name, String packageName)
 
   {
-    Package pkg = Packages.findPackage(packageName);
+    Package pkg = getCurrentPackage().findPackage(packageName);
     if (pkg == null)
       error(new LispError(packageName + " is not the name of a package."));
     return pkg.intern(name);
@@ -2338,7 +2360,8 @@ public final class Lisp
     // Common features
     LispObject featureList = list(Keyword.ARMEDBEAR, Keyword.ABCL,
                                   Keyword.COMMON_LISP, Keyword.ANSI_CL,
-                                  Keyword.CDR6, Keyword.MOP);
+                                  Keyword.CDR6, Keyword.MOP,
+                                  internKeyword("PACKAGE-LOCAL-NICKNAMES"));
     // OS type
     if (osName.startsWith("Linux"))
       featureList = Primitives.APPEND.execute(list(Keyword.UNIX,
