@@ -2,7 +2,7 @@
  * Load.java
  *
  * Copyright (C) 2002-2007 Peter Graves
- * $Id: Load.java 14194 2012-10-13 13:20:48Z mevenson $
+ * $Id$
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -125,15 +125,33 @@ public final class Load
                                         boolean print,
                                         boolean ifDoesNotExist)
     {
-        return load(pathname, verbose, print, ifDoesNotExist, false);
+        return load(pathname, verbose, print, ifDoesNotExist, false, Keyword.DEFAULT);
     }
+  
+    public static final LispObject load(InputStream in) 
+    {
+      return load(in, new SimpleString("UTF-8"));
+    }
+  
+    public static  final LispObject load(InputStream in, LispObject format) {
+        Stream stream = new Stream(Symbol.SYSTEM_STREAM, in, Symbol.CHARACTER, 
+                                   format);
+        final LispThread thread = LispThread.currentThread();
+        return loadFileFromStream(null, 
+                                  null,
+                                  stream,
+                                  Symbol.LOAD_VERBOSE.symbolValue(thread) != NIL,
+                                  Symbol.LOAD_PRINT.symbolValue(thread) != NIL,
+                                  false);
+    }
+
 
     public static final LispObject load(final Pathname pathname,
                                         boolean verbose,
                                         boolean print,
                                         boolean ifDoesNotExist,
-                                        boolean returnLastResult)
-
+                                        boolean returnLastResult,
+                                        LispObject externalFormat)
     {
         Pathname mergedPathname = null;
         if (!pathname.isAbsolute() && !pathname.isJar()) {
@@ -204,7 +222,7 @@ public final class Load
     
         try {
             return loadFileFromStream(pathname, truename,
-                                      new Stream(Symbol.SYSTEM_STREAM, in, Symbol.CHARACTER),
+                                      new Stream(Symbol.SYSTEM_STREAM, in, Symbol.CHARACTER, externalFormat),
                                       verbose, print, false, returnLastResult);
         }
         finally {
@@ -271,7 +289,6 @@ public final class Load
                                                   boolean verbose,
                                                   boolean print,
                                                   boolean auto)
-
     {
         InputStream in = null;
         Pathname pathname = null;
@@ -324,6 +341,7 @@ public final class Load
             && truename.type.princToString().equals(COMPILE_FILE_TYPE) && Utilities.checkZipFile(truename))  {
             Pathname init = new Pathname(truename.getNamestring());
             init.type = COMPILE_FILE_INIT_FASL_TYPE;
+            init.name = new SimpleString("__loader__");
             LispObject t = Pathname.truename(init);
             if (t instanceof Pathname) {
                 truename = (Pathname)t;
@@ -376,7 +394,7 @@ public final class Load
     // ### *fasl-version*
     // internal symbol
     static final Symbol _FASL_VERSION_ =
-        exportConstant("*FASL-VERSION*", PACKAGE_SYS, Fixnum.getInstance(39));
+        exportConstant("*FASL-VERSION*", PACKAGE_SYS, Fixnum.getInstance(42));
 
     // ### *fasl-external-format*
     // internal symbol
@@ -444,7 +462,8 @@ public final class Load
                         + second.princToString() + "' but expected '"
                         + _FASL_VERSION_.getSymbolValue().princToString()
                         + "' in "
-                        + Symbol.LOAD_PATHNAME.symbolValue(thread).princToString()));
+                        + Symbol.LOAD_PATHNAME.symbolValue(thread).princToString()
+                        + " (try recompiling the file)"));
         }
     }
 
@@ -483,6 +502,7 @@ public final class Load
         for (Symbol special : savedSpecials)
             thread.bindSpecialToCurrentValue(special);
 
+        thread.bindSpecial(_BACKQUOTE_COUNT_, Fixnum.getInstance(0));
         int loadDepth = Fixnum.getValue(_LOAD_DEPTH_.symbolValue(thread));
         thread.bindSpecial(_LOAD_DEPTH_, Fixnum.getInstance(++loadDepth));
         final String prefix = getLoadVerbosePrefix(loadDepth);
@@ -538,8 +558,11 @@ public final class Load
                         // between the "jar:jar:http:" and "jar:jar:file:"
                         // cases but this currently passes the tests.
                         if (!(truePathname.device.car() instanceof AbstractString)) {
-                            truePathname = (Pathname)truePathname.device.car();
-                            truePathname.invalidateNamestring();
+                          assert truePathname.device.car() instanceof Pathname;
+                          Pathname p = new Pathname((Pathname)truePathname.device.car());
+                          truePathname 
+                            = (Pathname) probe_file.PROBE_FILE.execute(p);
+                          truePathname.invalidateNamestring();
                         }
                     }
                     thread.bindSpecial(Symbol.LOAD_TRUENAME, truePathname);
@@ -655,44 +678,47 @@ public final class Load
     }
 
 
-    // ### %load filespec verbose print if-does-not-exist => generalized-boolean
+    // ### %load filespec verbose print if-does-not-exist external-format=> generalized-boolean
     private static final Primitive _LOAD = new _load();
     private static class _load extends Primitive {
         _load() {
             super("%load", PACKAGE_SYS, false,
-                  "filespec verbose print if-does-not-exist");
+                  "filespec verbose print if-does-not-exist external-format");
         }
         @Override
         public LispObject execute(LispObject filespec, LispObject verbose,
-                                  LispObject print, LispObject ifDoesNotExist)
+                                  LispObject print, LispObject ifDoesNotExist, 
+                                  LispObject externalFormat)
         {
-            return load(filespec, verbose, print, ifDoesNotExist, NIL);
+            return load(filespec, verbose, print, ifDoesNotExist, NIL, externalFormat);
         }
     }
 
-    // ### %load-returning-last-result filespec verbose print if-does-not-exist => object
+    // ### %load-returning-last-result filespec verbose print if-does-not-exist external-format => object
     private static final Primitive _LOAD_RETURNING_LAST_RESULT = new _load_returning_last_result();
     private static class _load_returning_last_result extends Primitive {
         _load_returning_last_result() {
             super("%load-returning-last-result", PACKAGE_SYS, false,
-                  "filespec verbose print if-does-not-exist");
+                  "filespec verbose print if-does-not-exist external-format");
         }
         @Override
         public LispObject execute(LispObject filespec, LispObject verbose,
-                                  LispObject print, LispObject ifDoesNotExist)
-            {
-            return load(filespec, verbose, print, ifDoesNotExist, T);
+                                  LispObject print, LispObject ifDoesNotExist, 
+                                  LispObject externalFormat) {
+             return load(filespec, verbose, print, ifDoesNotExist, T, externalFormat);
         }
     }
 
     static final LispObject load(LispObject filespec,
-                                         LispObject verbose,
-                                         LispObject print,
-                                         LispObject ifDoesNotExist,
-                                         LispObject returnLastResult)
+                                 LispObject verbose,
+                                 LispObject print,
+                                 LispObject ifDoesNotExist,
+                                 LispObject returnLastResult,
+                                 LispObject externalFormat)
         {
         if (filespec instanceof Stream) {
             if (((Stream)filespec).isOpen()) {
+                // !?! in this case the external-format specifier is ignored:  warn user?
                 LispObject pathname;
                 if (filespec instanceof FileStream)
                     pathname = ((FileStream)filespec).getPathname();
@@ -720,7 +746,8 @@ public final class Load
                     verbose != NIL,
                     print != NIL,
                     ifDoesNotExist != NIL,
-                    returnLastResult != NIL);
+                    returnLastResult != NIL,
+                    externalFormat);
     }
 
     // ### load-system-file
